# Generated from tptp_v7_0_0_0.g4 by ANTLR 4.7.2
from antlr4 import *

if __name__ is not None and "." in __name__:
    from .tptp_v7_0_0_0Parser import tptp_v7_0_0_0Parser
else:
    from tptp_v7_0_0_0Parser import tptp_v7_0_0_0Parser

# This class defines a complete listener for a parse tree produced by tptp_v7_0_0_0Parser.
class tptp_v7_0_0_0Listener(ParseTreeListener):

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tptp_file.
    def enterTptp_file(self, ctx: tptp_v7_0_0_0Parser.Tptp_fileContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tptp_file.
    def exitTptp_file(self, ctx: tptp_v7_0_0_0Parser.Tptp_fileContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tptp_input.
    def enterTptp_input(self, ctx: tptp_v7_0_0_0Parser.Tptp_inputContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tptp_input.
    def exitTptp_input(self, ctx: tptp_v7_0_0_0Parser.Tptp_inputContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#annotated_formula.
    def enterAnnotated_formula(self, ctx: tptp_v7_0_0_0Parser.Annotated_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#annotated_formula.
    def exitAnnotated_formula(self, ctx: tptp_v7_0_0_0Parser.Annotated_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tpi_annotated.
    def enterTpi_annotated(self, ctx: tptp_v7_0_0_0Parser.Tpi_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tpi_annotated.
    def exitTpi_annotated(self, ctx: tptp_v7_0_0_0Parser.Tpi_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tpi_formula.
    def enterTpi_formula(self, ctx: tptp_v7_0_0_0Parser.Tpi_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tpi_formula.
    def exitTpi_formula(self, ctx: tptp_v7_0_0_0Parser.Tpi_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_annotated.
    def enterThf_annotated(self, ctx: tptp_v7_0_0_0Parser.Thf_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_annotated.
    def exitThf_annotated(self, ctx: tptp_v7_0_0_0Parser.Thf_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tfx_annotated.
    def enterTfx_annotated(self, ctx: tptp_v7_0_0_0Parser.Tfx_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tfx_annotated.
    def exitTfx_annotated(self, ctx: tptp_v7_0_0_0Parser.Tfx_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_annotated.
    def enterTff_annotated(self, ctx: tptp_v7_0_0_0Parser.Tff_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_annotated.
    def exitTff_annotated(self, ctx: tptp_v7_0_0_0Parser.Tff_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tcf_annotated.
    def enterTcf_annotated(self, ctx: tptp_v7_0_0_0Parser.Tcf_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tcf_annotated.
    def exitTcf_annotated(self, ctx: tptp_v7_0_0_0Parser.Tcf_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_annotated.
    def enterFof_annotated(self, ctx: tptp_v7_0_0_0Parser.Fof_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_annotated.
    def exitFof_annotated(self, ctx: tptp_v7_0_0_0Parser.Fof_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#cnf_annotated.
    def enterCnf_annotated(self, ctx: tptp_v7_0_0_0Parser.Cnf_annotatedContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#cnf_annotated.
    def exitCnf_annotated(self, ctx: tptp_v7_0_0_0Parser.Cnf_annotatedContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#annotations.
    def enterAnnotations(self, ctx: tptp_v7_0_0_0Parser.AnnotationsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#annotations.
    def exitAnnotations(self, ctx: tptp_v7_0_0_0Parser.AnnotationsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#formula_role.
    def enterFormula_role(self, ctx: tptp_v7_0_0_0Parser.Formula_roleContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#formula_role.
    def exitFormula_role(self, ctx: tptp_v7_0_0_0Parser.Formula_roleContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_formula.
    def enterThf_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_formula.
    def exitThf_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_logic_formula.
    def enterThf_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_logic_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_logic_formula.
    def exitThf_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_logic_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_formula.
    def enterThf_binary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_binary_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_formula.
    def exitThf_binary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_binary_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_pair.
    def enterThf_binary_pair(self, ctx: tptp_v7_0_0_0Parser.Thf_binary_pairContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_pair.
    def exitThf_binary_pair(self, ctx: tptp_v7_0_0_0Parser.Thf_binary_pairContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_tuple.
    def enterThf_binary_tuple(self, ctx: tptp_v7_0_0_0Parser.Thf_binary_tupleContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_tuple.
    def exitThf_binary_tuple(self, ctx: tptp_v7_0_0_0Parser.Thf_binary_tupleContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_or_formula.
    def enterThf_or_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_or_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_or_formula.
    def exitThf_or_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_or_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_and_formula.
    def enterThf_and_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_and_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_and_formula.
    def exitThf_and_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_and_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_apply_formula.
    def enterThf_apply_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_apply_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_apply_formula.
    def exitThf_apply_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_apply_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_unitary_formula.
    def enterThf_unitary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_unitary_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_unitary_formula.
    def exitThf_unitary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_unitary_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_quantified_formula.
    def enterThf_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_quantified_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_quantified_formula.
    def exitThf_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_quantified_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_quantification.
    def enterThf_quantification(
        self, ctx: tptp_v7_0_0_0Parser.Thf_quantificationContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_quantification.
    def exitThf_quantification(
        self, ctx: tptp_v7_0_0_0Parser.Thf_quantificationContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_variable_list.
    def enterThf_variable_list(self, ctx: tptp_v7_0_0_0Parser.Thf_variable_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_variable_list.
    def exitThf_variable_list(self, ctx: tptp_v7_0_0_0Parser.Thf_variable_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_variable.
    def enterThf_variable(self, ctx: tptp_v7_0_0_0Parser.Thf_variableContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_variable.
    def exitThf_variable(self, ctx: tptp_v7_0_0_0Parser.Thf_variableContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_typed_variable.
    def enterThf_typed_variable(
        self, ctx: tptp_v7_0_0_0Parser.Thf_typed_variableContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_typed_variable.
    def exitThf_typed_variable(
        self, ctx: tptp_v7_0_0_0Parser.Thf_typed_variableContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_unary_formula.
    def enterThf_unary_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_unary_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_unary_formula.
    def exitThf_unary_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_unary_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_atom.
    def enterThf_atom(self, ctx: tptp_v7_0_0_0Parser.Thf_atomContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_atom.
    def exitThf_atom(self, ctx: tptp_v7_0_0_0Parser.Thf_atomContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_function.
    def enterThf_function(self, ctx: tptp_v7_0_0_0Parser.Thf_functionContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_function.
    def exitThf_function(self, ctx: tptp_v7_0_0_0Parser.Thf_functionContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_conn_term.
    def enterThf_conn_term(self, ctx: tptp_v7_0_0_0Parser.Thf_conn_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_conn_term.
    def exitThf_conn_term(self, ctx: tptp_v7_0_0_0Parser.Thf_conn_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_conditional.
    def enterThf_conditional(self, ctx: tptp_v7_0_0_0Parser.Thf_conditionalContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_conditional.
    def exitThf_conditional(self, ctx: tptp_v7_0_0_0Parser.Thf_conditionalContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_let.
    def enterThf_let(self, ctx: tptp_v7_0_0_0Parser.Thf_letContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_let.
    def exitThf_let(self, ctx: tptp_v7_0_0_0Parser.Thf_letContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_arguments.
    def enterThf_arguments(self, ctx: tptp_v7_0_0_0Parser.Thf_argumentsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_arguments.
    def exitThf_arguments(self, ctx: tptp_v7_0_0_0Parser.Thf_argumentsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_type_formula.
    def enterThf_type_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_type_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_type_formula.
    def exitThf_type_formula(self, ctx: tptp_v7_0_0_0Parser.Thf_type_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_typeable_formula.
    def enterThf_typeable_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_typeable_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_typeable_formula.
    def exitThf_typeable_formula(
        self, ctx: tptp_v7_0_0_0Parser.Thf_typeable_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_subtype.
    def enterThf_subtype(self, ctx: tptp_v7_0_0_0Parser.Thf_subtypeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_subtype.
    def exitThf_subtype(self, ctx: tptp_v7_0_0_0Parser.Thf_subtypeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_top_level_type.
    def enterThf_top_level_type(
        self, ctx: tptp_v7_0_0_0Parser.Thf_top_level_typeContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_top_level_type.
    def exitThf_top_level_type(
        self, ctx: tptp_v7_0_0_0Parser.Thf_top_level_typeContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_unitary_type.
    def enterThf_unitary_type(self, ctx: tptp_v7_0_0_0Parser.Thf_unitary_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_unitary_type.
    def exitThf_unitary_type(self, ctx: tptp_v7_0_0_0Parser.Thf_unitary_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_apply_type.
    def enterThf_apply_type(self, ctx: tptp_v7_0_0_0Parser.Thf_apply_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_apply_type.
    def exitThf_apply_type(self, ctx: tptp_v7_0_0_0Parser.Thf_apply_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_type.
    def enterThf_binary_type(self, ctx: tptp_v7_0_0_0Parser.Thf_binary_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_binary_type.
    def exitThf_binary_type(self, ctx: tptp_v7_0_0_0Parser.Thf_binary_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_mapping_type.
    def enterThf_mapping_type(self, ctx: tptp_v7_0_0_0Parser.Thf_mapping_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_mapping_type.
    def exitThf_mapping_type(self, ctx: tptp_v7_0_0_0Parser.Thf_mapping_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_xprod_type.
    def enterThf_xprod_type(self, ctx: tptp_v7_0_0_0Parser.Thf_xprod_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_xprod_type.
    def exitThf_xprod_type(self, ctx: tptp_v7_0_0_0Parser.Thf_xprod_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_union_type.
    def enterThf_union_type(self, ctx: tptp_v7_0_0_0Parser.Thf_union_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_union_type.
    def exitThf_union_type(self, ctx: tptp_v7_0_0_0Parser.Thf_union_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_sequent.
    def enterThf_sequent(self, ctx: tptp_v7_0_0_0Parser.Thf_sequentContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_sequent.
    def exitThf_sequent(self, ctx: tptp_v7_0_0_0Parser.Thf_sequentContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_tuple.
    def enterThf_tuple(self, ctx: tptp_v7_0_0_0Parser.Thf_tupleContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_tuple.
    def exitThf_tuple(self, ctx: tptp_v7_0_0_0Parser.Thf_tupleContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_formula_list.
    def enterThf_formula_list(self, ctx: tptp_v7_0_0_0Parser.Thf_formula_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_formula_list.
    def exitThf_formula_list(self, ctx: tptp_v7_0_0_0Parser.Thf_formula_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tfx_formula.
    def enterTfx_formula(self, ctx: tptp_v7_0_0_0Parser.Tfx_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tfx_formula.
    def exitTfx_formula(self, ctx: tptp_v7_0_0_0Parser.Tfx_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tfx_logic_formula.
    def enterTfx_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Tfx_logic_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tfx_logic_formula.
    def exitTfx_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Tfx_logic_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_formula.
    def enterTff_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_formula.
    def exitTff_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_logic_formula.
    def enterTff_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_logic_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_logic_formula.
    def exitTff_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_logic_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_binary_formula.
    def enterTff_binary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_binary_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_binary_formula.
    def exitTff_binary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_binary_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_binary_nonassoc.
    def enterTff_binary_nonassoc(
        self, ctx: tptp_v7_0_0_0Parser.Tff_binary_nonassocContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_binary_nonassoc.
    def exitTff_binary_nonassoc(
        self, ctx: tptp_v7_0_0_0Parser.Tff_binary_nonassocContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_binary_assoc.
    def enterTff_binary_assoc(self, ctx: tptp_v7_0_0_0Parser.Tff_binary_assocContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_binary_assoc.
    def exitTff_binary_assoc(self, ctx: tptp_v7_0_0_0Parser.Tff_binary_assocContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_or_formula.
    def enterTff_or_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_or_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_or_formula.
    def exitTff_or_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_or_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_and_formula.
    def enterTff_and_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_and_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_and_formula.
    def exitTff_and_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_and_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_unitary_formula.
    def enterTff_unitary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_unitary_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_unitary_formula.
    def exitTff_unitary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_unitary_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_quantified_formula.
    def enterTff_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_quantified_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_quantified_formula.
    def exitTff_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_quantified_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_variable_list.
    def enterTff_variable_list(self, ctx: tptp_v7_0_0_0Parser.Tff_variable_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_variable_list.
    def exitTff_variable_list(self, ctx: tptp_v7_0_0_0Parser.Tff_variable_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_variable.
    def enterTff_variable(self, ctx: tptp_v7_0_0_0Parser.Tff_variableContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_variable.
    def exitTff_variable(self, ctx: tptp_v7_0_0_0Parser.Tff_variableContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_typed_variable.
    def enterTff_typed_variable(
        self, ctx: tptp_v7_0_0_0Parser.Tff_typed_variableContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_typed_variable.
    def exitTff_typed_variable(
        self, ctx: tptp_v7_0_0_0Parser.Tff_typed_variableContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_unary_formula.
    def enterTff_unary_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_unary_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_unary_formula.
    def exitTff_unary_formula(self, ctx: tptp_v7_0_0_0Parser.Tff_unary_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_atomic_formula.
    def enterTff_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_atomic_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_atomic_formula.
    def exitTff_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tff_atomic_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_conditional.
    def enterTff_conditional(self, ctx: tptp_v7_0_0_0Parser.Tff_conditionalContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_conditional.
    def exitTff_conditional(self, ctx: tptp_v7_0_0_0Parser.Tff_conditionalContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let.
    def enterTff_let(self, ctx: tptp_v7_0_0_0Parser.Tff_letContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let.
    def exitTff_let(self, ctx: tptp_v7_0_0_0Parser.Tff_letContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_defns.
    def enterTff_let_term_defns(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_defnsContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_defns.
    def exitTff_let_term_defns(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_defnsContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_list.
    def enterTff_let_term_list(self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_list.
    def exitTff_let_term_list(self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_defn.
    def enterTff_let_term_defn(self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_defnContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_defn.
    def exitTff_let_term_defn(self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_defnContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_binding.
    def enterTff_let_term_binding(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_bindingContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term_binding.
    def exitTff_let_term_binding(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_term_bindingContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_defns.
    def enterTff_let_formula_defns(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_defnsContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_defns.
    def exitTff_let_formula_defns(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_defnsContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_list.
    def enterTff_let_formula_list(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_listContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_list.
    def exitTff_let_formula_list(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_listContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_defn.
    def enterTff_let_formula_defn(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_defnContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_defn.
    def exitTff_let_formula_defn(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_defnContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_binding.
    def enterTff_let_formula_binding(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_bindingContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_formula_binding.
    def exitTff_let_formula_binding(
        self, ctx: tptp_v7_0_0_0Parser.Tff_let_formula_bindingContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_sequent.
    def enterTff_sequent(self, ctx: tptp_v7_0_0_0Parser.Tff_sequentContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_sequent.
    def exitTff_sequent(self, ctx: tptp_v7_0_0_0Parser.Tff_sequentContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_formula_tuple.
    def enterTff_formula_tuple(self, ctx: tptp_v7_0_0_0Parser.Tff_formula_tupleContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_formula_tuple.
    def exitTff_formula_tuple(self, ctx: tptp_v7_0_0_0Parser.Tff_formula_tupleContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_formula_tuple_list.
    def enterTff_formula_tuple_list(
        self, ctx: tptp_v7_0_0_0Parser.Tff_formula_tuple_listContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_formula_tuple_list.
    def exitTff_formula_tuple_list(
        self, ctx: tptp_v7_0_0_0Parser.Tff_formula_tuple_listContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_typed_atom.
    def enterTff_typed_atom(self, ctx: tptp_v7_0_0_0Parser.Tff_typed_atomContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_typed_atom.
    def exitTff_typed_atom(self, ctx: tptp_v7_0_0_0Parser.Tff_typed_atomContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_subtype.
    def enterTff_subtype(self, ctx: tptp_v7_0_0_0Parser.Tff_subtypeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_subtype.
    def exitTff_subtype(self, ctx: tptp_v7_0_0_0Parser.Tff_subtypeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_top_level_type.
    def enterTff_top_level_type(
        self, ctx: tptp_v7_0_0_0Parser.Tff_top_level_typeContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_top_level_type.
    def exitTff_top_level_type(
        self, ctx: tptp_v7_0_0_0Parser.Tff_top_level_typeContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tf1_quantified_type.
    def enterTf1_quantified_type(
        self, ctx: tptp_v7_0_0_0Parser.Tf1_quantified_typeContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tf1_quantified_type.
    def exitTf1_quantified_type(
        self, ctx: tptp_v7_0_0_0Parser.Tf1_quantified_typeContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_monotype.
    def enterTff_monotype(self, ctx: tptp_v7_0_0_0Parser.Tff_monotypeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_monotype.
    def exitTff_monotype(self, ctx: tptp_v7_0_0_0Parser.Tff_monotypeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_unitary_type.
    def enterTff_unitary_type(self, ctx: tptp_v7_0_0_0Parser.Tff_unitary_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_unitary_type.
    def exitTff_unitary_type(self, ctx: tptp_v7_0_0_0Parser.Tff_unitary_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_atomic_type.
    def enterTff_atomic_type(self, ctx: tptp_v7_0_0_0Parser.Tff_atomic_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_atomic_type.
    def exitTff_atomic_type(self, ctx: tptp_v7_0_0_0Parser.Tff_atomic_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_type_arguments.
    def enterTff_type_arguments(
        self, ctx: tptp_v7_0_0_0Parser.Tff_type_argumentsContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_type_arguments.
    def exitTff_type_arguments(
        self, ctx: tptp_v7_0_0_0Parser.Tff_type_argumentsContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_mapping_type.
    def enterTff_mapping_type(self, ctx: tptp_v7_0_0_0Parser.Tff_mapping_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_mapping_type.
    def exitTff_mapping_type(self, ctx: tptp_v7_0_0_0Parser.Tff_mapping_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_xprod_type.
    def enterTff_xprod_type(self, ctx: tptp_v7_0_0_0Parser.Tff_xprod_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_xprod_type.
    def exitTff_xprod_type(self, ctx: tptp_v7_0_0_0Parser.Tff_xprod_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tcf_formula.
    def enterTcf_formula(self, ctx: tptp_v7_0_0_0Parser.Tcf_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tcf_formula.
    def exitTcf_formula(self, ctx: tptp_v7_0_0_0Parser.Tcf_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tcf_logic_formula.
    def enterTcf_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Tcf_logic_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tcf_logic_formula.
    def exitTcf_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Tcf_logic_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tcf_quantified_formula.
    def enterTcf_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tcf_quantified_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tcf_quantified_formula.
    def exitTcf_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Tcf_quantified_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_formula.
    def enterFof_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_formula.
    def exitFof_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_logic_formula.
    def enterFof_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_logic_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_logic_formula.
    def exitFof_logic_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_logic_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_binary_formula.
    def enterFof_binary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_binary_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_binary_formula.
    def exitFof_binary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_binary_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_binary_nonassoc.
    def enterFof_binary_nonassoc(
        self, ctx: tptp_v7_0_0_0Parser.Fof_binary_nonassocContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_binary_nonassoc.
    def exitFof_binary_nonassoc(
        self, ctx: tptp_v7_0_0_0Parser.Fof_binary_nonassocContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_binary_assoc.
    def enterFof_binary_assoc(self, ctx: tptp_v7_0_0_0Parser.Fof_binary_assocContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_binary_assoc.
    def exitFof_binary_assoc(self, ctx: tptp_v7_0_0_0Parser.Fof_binary_assocContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_or_formula.
    def enterFof_or_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_or_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_or_formula.
    def exitFof_or_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_or_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_and_formula.
    def enterFof_and_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_and_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_and_formula.
    def exitFof_and_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_and_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_unitary_formula.
    def enterFof_unitary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_unitary_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_unitary_formula.
    def exitFof_unitary_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_unitary_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_quantified_formula.
    def enterFof_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_quantified_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_quantified_formula.
    def exitFof_quantified_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_quantified_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_variable_list.
    def enterFof_variable_list(self, ctx: tptp_v7_0_0_0Parser.Fof_variable_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_variable_list.
    def exitFof_variable_list(self, ctx: tptp_v7_0_0_0Parser.Fof_variable_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_unary_formula.
    def enterFof_unary_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_unary_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_unary_formula.
    def exitFof_unary_formula(self, ctx: tptp_v7_0_0_0Parser.Fof_unary_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_infix_unary.
    def enterFof_infix_unary(self, ctx: tptp_v7_0_0_0Parser.Fof_infix_unaryContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_infix_unary.
    def exitFof_infix_unary(self, ctx: tptp_v7_0_0_0Parser.Fof_infix_unaryContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_atomic_formula.
    def enterFof_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_atomic_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_atomic_formula.
    def exitFof_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_atomic_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_plain_atomic_formula.
    def enterFof_plain_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_plain_atomic_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_plain_atomic_formula.
    def exitFof_plain_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_plain_atomic_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_atomic_formula.
    def enterFof_defined_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_atomic_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_atomic_formula.
    def exitFof_defined_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_atomic_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_plain_formula.
    def enterFof_defined_plain_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_plain_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_plain_formula.
    def exitFof_defined_plain_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_plain_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_infix_formula.
    def enterFof_defined_infix_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_infix_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_infix_formula.
    def exitFof_defined_infix_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_infix_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_system_atomic_formula.
    def enterFof_system_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_system_atomic_formulaContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_system_atomic_formula.
    def exitFof_system_atomic_formula(
        self, ctx: tptp_v7_0_0_0Parser.Fof_system_atomic_formulaContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_plain_term.
    def enterFof_plain_term(self, ctx: tptp_v7_0_0_0Parser.Fof_plain_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_plain_term.
    def exitFof_plain_term(self, ctx: tptp_v7_0_0_0Parser.Fof_plain_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_term.
    def enterFof_defined_term(self, ctx: tptp_v7_0_0_0Parser.Fof_defined_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_term.
    def exitFof_defined_term(self, ctx: tptp_v7_0_0_0Parser.Fof_defined_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_atomic_term.
    def enterFof_defined_atomic_term(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_atomic_termContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_atomic_term.
    def exitFof_defined_atomic_term(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_atomic_termContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_plain_term.
    def enterFof_defined_plain_term(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_plain_termContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_defined_plain_term.
    def exitFof_defined_plain_term(
        self, ctx: tptp_v7_0_0_0Parser.Fof_defined_plain_termContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_system_term.
    def enterFof_system_term(self, ctx: tptp_v7_0_0_0Parser.Fof_system_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_system_term.
    def exitFof_system_term(self, ctx: tptp_v7_0_0_0Parser.Fof_system_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_arguments.
    def enterFof_arguments(self, ctx: tptp_v7_0_0_0Parser.Fof_argumentsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_arguments.
    def exitFof_arguments(self, ctx: tptp_v7_0_0_0Parser.Fof_argumentsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_term.
    def enterFof_term(self, ctx: tptp_v7_0_0_0Parser.Fof_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_term.
    def exitFof_term(self, ctx: tptp_v7_0_0_0Parser.Fof_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_function_term.
    def enterFof_function_term(self, ctx: tptp_v7_0_0_0Parser.Fof_function_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_function_term.
    def exitFof_function_term(self, ctx: tptp_v7_0_0_0Parser.Fof_function_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_conditional_term.
    def enterTff_conditional_term(
        self, ctx: tptp_v7_0_0_0Parser.Tff_conditional_termContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_conditional_term.
    def exitTff_conditional_term(
        self, ctx: tptp_v7_0_0_0Parser.Tff_conditional_termContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term.
    def enterTff_let_term(self, ctx: tptp_v7_0_0_0Parser.Tff_let_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_let_term.
    def exitTff_let_term(self, ctx: tptp_v7_0_0_0Parser.Tff_let_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_tuple_term.
    def enterTff_tuple_term(self, ctx: tptp_v7_0_0_0Parser.Tff_tuple_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_tuple_term.
    def exitTff_tuple_term(self, ctx: tptp_v7_0_0_0Parser.Tff_tuple_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_sequent.
    def enterFof_sequent(self, ctx: tptp_v7_0_0_0Parser.Fof_sequentContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_sequent.
    def exitFof_sequent(self, ctx: tptp_v7_0_0_0Parser.Fof_sequentContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_formula_tuple.
    def enterFof_formula_tuple(self, ctx: tptp_v7_0_0_0Parser.Fof_formula_tupleContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_formula_tuple.
    def exitFof_formula_tuple(self, ctx: tptp_v7_0_0_0Parser.Fof_formula_tupleContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_formula_tuple_list.
    def enterFof_formula_tuple_list(
        self, ctx: tptp_v7_0_0_0Parser.Fof_formula_tuple_listContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_formula_tuple_list.
    def exitFof_formula_tuple_list(
        self, ctx: tptp_v7_0_0_0Parser.Fof_formula_tuple_listContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#cnf_formula.
    def enterCnf_formula(self, ctx: tptp_v7_0_0_0Parser.Cnf_formulaContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#cnf_formula.
    def exitCnf_formula(self, ctx: tptp_v7_0_0_0Parser.Cnf_formulaContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#cnf_disjunction.
    def enterCnf_disjunction(self, ctx: tptp_v7_0_0_0Parser.Cnf_disjunctionContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#cnf_disjunction.
    def exitCnf_disjunction(self, ctx: tptp_v7_0_0_0Parser.Cnf_disjunctionContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#cnf_literal.
    def enterCnf_literal(self, ctx: tptp_v7_0_0_0Parser.Cnf_literalContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#cnf_literal.
    def exitCnf_literal(self, ctx: tptp_v7_0_0_0Parser.Cnf_literalContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_quantifier.
    def enterThf_quantifier(self, ctx: tptp_v7_0_0_0Parser.Thf_quantifierContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_quantifier.
    def exitThf_quantifier(self, ctx: tptp_v7_0_0_0Parser.Thf_quantifierContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#th0_quantifier.
    def enterTh0_quantifier(self, ctx: tptp_v7_0_0_0Parser.Th0_quantifierContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#th0_quantifier.
    def exitTh0_quantifier(self, ctx: tptp_v7_0_0_0Parser.Th0_quantifierContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#th1_quantifier.
    def enterTh1_quantifier(self, ctx: tptp_v7_0_0_0Parser.Th1_quantifierContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#th1_quantifier.
    def exitTh1_quantifier(self, ctx: tptp_v7_0_0_0Parser.Th1_quantifierContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_pair_connective.
    def enterThf_pair_connective(
        self, ctx: tptp_v7_0_0_0Parser.Thf_pair_connectiveContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_pair_connective.
    def exitThf_pair_connective(
        self, ctx: tptp_v7_0_0_0Parser.Thf_pair_connectiveContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#thf_unary_connective.
    def enterThf_unary_connective(
        self, ctx: tptp_v7_0_0_0Parser.Thf_unary_connectiveContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#thf_unary_connective.
    def exitThf_unary_connective(
        self, ctx: tptp_v7_0_0_0Parser.Thf_unary_connectiveContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#th1_unary_connective.
    def enterTh1_unary_connective(
        self, ctx: tptp_v7_0_0_0Parser.Th1_unary_connectiveContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#th1_unary_connective.
    def exitTh1_unary_connective(
        self, ctx: tptp_v7_0_0_0Parser.Th1_unary_connectiveContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#tff_pair_connective.
    def enterTff_pair_connective(
        self, ctx: tptp_v7_0_0_0Parser.Tff_pair_connectiveContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#tff_pair_connective.
    def exitTff_pair_connective(
        self, ctx: tptp_v7_0_0_0Parser.Tff_pair_connectiveContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#fof_quantifier.
    def enterFof_quantifier(self, ctx: tptp_v7_0_0_0Parser.Fof_quantifierContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#fof_quantifier.
    def exitFof_quantifier(self, ctx: tptp_v7_0_0_0Parser.Fof_quantifierContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#binary_connective.
    def enterBinary_connective(self, ctx: tptp_v7_0_0_0Parser.Binary_connectiveContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#binary_connective.
    def exitBinary_connective(self, ctx: tptp_v7_0_0_0Parser.Binary_connectiveContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#assoc_connective.
    def enterAssoc_connective(self, ctx: tptp_v7_0_0_0Parser.Assoc_connectiveContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#assoc_connective.
    def exitAssoc_connective(self, ctx: tptp_v7_0_0_0Parser.Assoc_connectiveContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#unary_connective.
    def enterUnary_connective(self, ctx: tptp_v7_0_0_0Parser.Unary_connectiveContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#unary_connective.
    def exitUnary_connective(self, ctx: tptp_v7_0_0_0Parser.Unary_connectiveContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#type_constant.
    def enterType_constant(self, ctx: tptp_v7_0_0_0Parser.Type_constantContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#type_constant.
    def exitType_constant(self, ctx: tptp_v7_0_0_0Parser.Type_constantContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#type_functor.
    def enterType_functor(self, ctx: tptp_v7_0_0_0Parser.Type_functorContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#type_functor.
    def exitType_functor(self, ctx: tptp_v7_0_0_0Parser.Type_functorContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_type.
    def enterDefined_type(self, ctx: tptp_v7_0_0_0Parser.Defined_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_type.
    def exitDefined_type(self, ctx: tptp_v7_0_0_0Parser.Defined_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#system_type.
    def enterSystem_type(self, ctx: tptp_v7_0_0_0Parser.System_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#system_type.
    def exitSystem_type(self, ctx: tptp_v7_0_0_0Parser.System_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#atom.
    def enterAtom(self, ctx: tptp_v7_0_0_0Parser.AtomContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#atom.
    def exitAtom(self, ctx: tptp_v7_0_0_0Parser.AtomContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#untyped_atom.
    def enterUntyped_atom(self, ctx: tptp_v7_0_0_0Parser.Untyped_atomContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#untyped_atom.
    def exitUntyped_atom(self, ctx: tptp_v7_0_0_0Parser.Untyped_atomContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_proposition.
    def enterDefined_proposition(
        self, ctx: tptp_v7_0_0_0Parser.Defined_propositionContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_proposition.
    def exitDefined_proposition(
        self, ctx: tptp_v7_0_0_0Parser.Defined_propositionContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_predicate.
    def enterDefined_predicate(self, ctx: tptp_v7_0_0_0Parser.Defined_predicateContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_predicate.
    def exitDefined_predicate(self, ctx: tptp_v7_0_0_0Parser.Defined_predicateContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_infix_pred.
    def enterDefined_infix_pred(
        self, ctx: tptp_v7_0_0_0Parser.Defined_infix_predContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_infix_pred.
    def exitDefined_infix_pred(
        self, ctx: tptp_v7_0_0_0Parser.Defined_infix_predContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#constant.
    def enterConstant(self, ctx: tptp_v7_0_0_0Parser.ConstantContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#constant.
    def exitConstant(self, ctx: tptp_v7_0_0_0Parser.ConstantContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#functor.
    def enterFunctor(self, ctx: tptp_v7_0_0_0Parser.FunctorContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#functor.
    def exitFunctor(self, ctx: tptp_v7_0_0_0Parser.FunctorContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#system_constant.
    def enterSystem_constant(self, ctx: tptp_v7_0_0_0Parser.System_constantContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#system_constant.
    def exitSystem_constant(self, ctx: tptp_v7_0_0_0Parser.System_constantContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#system_functor.
    def enterSystem_functor(self, ctx: tptp_v7_0_0_0Parser.System_functorContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#system_functor.
    def exitSystem_functor(self, ctx: tptp_v7_0_0_0Parser.System_functorContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_constant.
    def enterDefined_constant(self, ctx: tptp_v7_0_0_0Parser.Defined_constantContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_constant.
    def exitDefined_constant(self, ctx: tptp_v7_0_0_0Parser.Defined_constantContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_functor.
    def enterDefined_functor(self, ctx: tptp_v7_0_0_0Parser.Defined_functorContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_functor.
    def exitDefined_functor(self, ctx: tptp_v7_0_0_0Parser.Defined_functorContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#defined_term.
    def enterDefined_term(self, ctx: tptp_v7_0_0_0Parser.Defined_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#defined_term.
    def exitDefined_term(self, ctx: tptp_v7_0_0_0Parser.Defined_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#variable.
    def enterVariable(self, ctx: tptp_v7_0_0_0Parser.VariableContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#variable.
    def exitVariable(self, ctx: tptp_v7_0_0_0Parser.VariableContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#source.
    def enterSource(self, ctx: tptp_v7_0_0_0Parser.SourceContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#source.
    def exitSource(self, ctx: tptp_v7_0_0_0Parser.SourceContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#sources.
    def enterSources(self, ctx: tptp_v7_0_0_0Parser.SourcesContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#sources.
    def exitSources(self, ctx: tptp_v7_0_0_0Parser.SourcesContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#dag_source.
    def enterDag_source(self, ctx: tptp_v7_0_0_0Parser.Dag_sourceContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#dag_source.
    def exitDag_source(self, ctx: tptp_v7_0_0_0Parser.Dag_sourceContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#inference_record.
    def enterInference_record(self, ctx: tptp_v7_0_0_0Parser.Inference_recordContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#inference_record.
    def exitInference_record(self, ctx: tptp_v7_0_0_0Parser.Inference_recordContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#inference_rule.
    def enterInference_rule(self, ctx: tptp_v7_0_0_0Parser.Inference_ruleContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#inference_rule.
    def exitInference_rule(self, ctx: tptp_v7_0_0_0Parser.Inference_ruleContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#inference_parents.
    def enterInference_parents(self, ctx: tptp_v7_0_0_0Parser.Inference_parentsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#inference_parents.
    def exitInference_parents(self, ctx: tptp_v7_0_0_0Parser.Inference_parentsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#parent_list.
    def enterParent_list(self, ctx: tptp_v7_0_0_0Parser.Parent_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#parent_list.
    def exitParent_list(self, ctx: tptp_v7_0_0_0Parser.Parent_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#parent_info.
    def enterParent_info(self, ctx: tptp_v7_0_0_0Parser.Parent_infoContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#parent_info.
    def exitParent_info(self, ctx: tptp_v7_0_0_0Parser.Parent_infoContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#parent_details.
    def enterParent_details(self, ctx: tptp_v7_0_0_0Parser.Parent_detailsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#parent_details.
    def exitParent_details(self, ctx: tptp_v7_0_0_0Parser.Parent_detailsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#internal_source.
    def enterInternal_source(self, ctx: tptp_v7_0_0_0Parser.Internal_sourceContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#internal_source.
    def exitInternal_source(self, ctx: tptp_v7_0_0_0Parser.Internal_sourceContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#intro_type.
    def enterIntro_type(self, ctx: tptp_v7_0_0_0Parser.Intro_typeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#intro_type.
    def exitIntro_type(self, ctx: tptp_v7_0_0_0Parser.Intro_typeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#external_source.
    def enterExternal_source(self, ctx: tptp_v7_0_0_0Parser.External_sourceContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#external_source.
    def exitExternal_source(self, ctx: tptp_v7_0_0_0Parser.External_sourceContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#file_source.
    def enterFile_source(self, ctx: tptp_v7_0_0_0Parser.File_sourceContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#file_source.
    def exitFile_source(self, ctx: tptp_v7_0_0_0Parser.File_sourceContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#file_info.
    def enterFile_info(self, ctx: tptp_v7_0_0_0Parser.File_infoContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#file_info.
    def exitFile_info(self, ctx: tptp_v7_0_0_0Parser.File_infoContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#theory.
    def enterTheory(self, ctx: tptp_v7_0_0_0Parser.TheoryContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#theory.
    def exitTheory(self, ctx: tptp_v7_0_0_0Parser.TheoryContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#theory_name.
    def enterTheory_name(self, ctx: tptp_v7_0_0_0Parser.Theory_nameContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#theory_name.
    def exitTheory_name(self, ctx: tptp_v7_0_0_0Parser.Theory_nameContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#creator_source.
    def enterCreator_source(self, ctx: tptp_v7_0_0_0Parser.Creator_sourceContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#creator_source.
    def exitCreator_source(self, ctx: tptp_v7_0_0_0Parser.Creator_sourceContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#creator_name.
    def enterCreator_name(self, ctx: tptp_v7_0_0_0Parser.Creator_nameContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#creator_name.
    def exitCreator_name(self, ctx: tptp_v7_0_0_0Parser.Creator_nameContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#optional_info.
    def enterOptional_info(self, ctx: tptp_v7_0_0_0Parser.Optional_infoContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#optional_info.
    def exitOptional_info(self, ctx: tptp_v7_0_0_0Parser.Optional_infoContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#useful_info.
    def enterUseful_info(self, ctx: tptp_v7_0_0_0Parser.Useful_infoContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#useful_info.
    def exitUseful_info(self, ctx: tptp_v7_0_0_0Parser.Useful_infoContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#info_items.
    def enterInfo_items(self, ctx: tptp_v7_0_0_0Parser.Info_itemsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#info_items.
    def exitInfo_items(self, ctx: tptp_v7_0_0_0Parser.Info_itemsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#info_item.
    def enterInfo_item(self, ctx: tptp_v7_0_0_0Parser.Info_itemContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#info_item.
    def exitInfo_item(self, ctx: tptp_v7_0_0_0Parser.Info_itemContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#formula_item.
    def enterFormula_item(self, ctx: tptp_v7_0_0_0Parser.Formula_itemContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#formula_item.
    def exitFormula_item(self, ctx: tptp_v7_0_0_0Parser.Formula_itemContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#description_item.
    def enterDescription_item(self, ctx: tptp_v7_0_0_0Parser.Description_itemContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#description_item.
    def exitDescription_item(self, ctx: tptp_v7_0_0_0Parser.Description_itemContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#iquote_item.
    def enterIquote_item(self, ctx: tptp_v7_0_0_0Parser.Iquote_itemContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#iquote_item.
    def exitIquote_item(self, ctx: tptp_v7_0_0_0Parser.Iquote_itemContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#inference_item.
    def enterInference_item(self, ctx: tptp_v7_0_0_0Parser.Inference_itemContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#inference_item.
    def exitInference_item(self, ctx: tptp_v7_0_0_0Parser.Inference_itemContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#inference_status.
    def enterInference_status(self, ctx: tptp_v7_0_0_0Parser.Inference_statusContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#inference_status.
    def exitInference_status(self, ctx: tptp_v7_0_0_0Parser.Inference_statusContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#status_value.
    def enterStatus_value(self, ctx: tptp_v7_0_0_0Parser.Status_valueContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#status_value.
    def exitStatus_value(self, ctx: tptp_v7_0_0_0Parser.Status_valueContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#inference_info.
    def enterInference_info(self, ctx: tptp_v7_0_0_0Parser.Inference_infoContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#inference_info.
    def exitInference_info(self, ctx: tptp_v7_0_0_0Parser.Inference_infoContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#assumptions_record.
    def enterAssumptions_record(
        self, ctx: tptp_v7_0_0_0Parser.Assumptions_recordContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#assumptions_record.
    def exitAssumptions_record(
        self, ctx: tptp_v7_0_0_0Parser.Assumptions_recordContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#refutation.
    def enterRefutation(self, ctx: tptp_v7_0_0_0Parser.RefutationContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#refutation.
    def exitRefutation(self, ctx: tptp_v7_0_0_0Parser.RefutationContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#new_symbol_record.
    def enterNew_symbol_record(self, ctx: tptp_v7_0_0_0Parser.New_symbol_recordContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#new_symbol_record.
    def exitNew_symbol_record(self, ctx: tptp_v7_0_0_0Parser.New_symbol_recordContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#new_symbol_list.
    def enterNew_symbol_list(self, ctx: tptp_v7_0_0_0Parser.New_symbol_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#new_symbol_list.
    def exitNew_symbol_list(self, ctx: tptp_v7_0_0_0Parser.New_symbol_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#principal_symbol.
    def enterPrincipal_symbol(self, ctx: tptp_v7_0_0_0Parser.Principal_symbolContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#principal_symbol.
    def exitPrincipal_symbol(self, ctx: tptp_v7_0_0_0Parser.Principal_symbolContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#include.
    def enterInclude(self, ctx: tptp_v7_0_0_0Parser.IncludeContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#include.
    def exitInclude(self, ctx: tptp_v7_0_0_0Parser.IncludeContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#formula_selection.
    def enterFormula_selection(self, ctx: tptp_v7_0_0_0Parser.Formula_selectionContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#formula_selection.
    def exitFormula_selection(self, ctx: tptp_v7_0_0_0Parser.Formula_selectionContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#name_list.
    def enterName_list(self, ctx: tptp_v7_0_0_0Parser.Name_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#name_list.
    def exitName_list(self, ctx: tptp_v7_0_0_0Parser.Name_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#general_term.
    def enterGeneral_term(self, ctx: tptp_v7_0_0_0Parser.General_termContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#general_term.
    def exitGeneral_term(self, ctx: tptp_v7_0_0_0Parser.General_termContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#general_data.
    def enterGeneral_data(self, ctx: tptp_v7_0_0_0Parser.General_dataContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#general_data.
    def exitGeneral_data(self, ctx: tptp_v7_0_0_0Parser.General_dataContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#general_function.
    def enterGeneral_function(self, ctx: tptp_v7_0_0_0Parser.General_functionContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#general_function.
    def exitGeneral_function(self, ctx: tptp_v7_0_0_0Parser.General_functionContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#formula_data.
    def enterFormula_data(self, ctx: tptp_v7_0_0_0Parser.Formula_dataContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#formula_data.
    def exitFormula_data(self, ctx: tptp_v7_0_0_0Parser.Formula_dataContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#general_list.
    def enterGeneral_list(self, ctx: tptp_v7_0_0_0Parser.General_listContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#general_list.
    def exitGeneral_list(self, ctx: tptp_v7_0_0_0Parser.General_listContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#general_terms.
    def enterGeneral_terms(self, ctx: tptp_v7_0_0_0Parser.General_termsContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#general_terms.
    def exitGeneral_terms(self, ctx: tptp_v7_0_0_0Parser.General_termsContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#name.
    def enterName(self, ctx: tptp_v7_0_0_0Parser.NameContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#name.
    def exitName(self, ctx: tptp_v7_0_0_0Parser.NameContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#atomic_word.
    def enterAtomic_word(self, ctx: tptp_v7_0_0_0Parser.Atomic_wordContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#atomic_word.
    def exitAtomic_word(self, ctx: tptp_v7_0_0_0Parser.Atomic_wordContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#atomic_defined_word.
    def enterAtomic_defined_word(
        self, ctx: tptp_v7_0_0_0Parser.Atomic_defined_wordContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#atomic_defined_word.
    def exitAtomic_defined_word(
        self, ctx: tptp_v7_0_0_0Parser.Atomic_defined_wordContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#atomic_system_word.
    def enterAtomic_system_word(
        self, ctx: tptp_v7_0_0_0Parser.Atomic_system_wordContext
    ):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#atomic_system_word.
    def exitAtomic_system_word(
        self, ctx: tptp_v7_0_0_0Parser.Atomic_system_wordContext
    ):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#number.
    def enterNumber(self, ctx: tptp_v7_0_0_0Parser.NumberContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#number.
    def exitNumber(self, ctx: tptp_v7_0_0_0Parser.NumberContext):
        pass

    # Enter a parse tree produced by tptp_v7_0_0_0Parser#file_name.
    def enterFile_name(self, ctx: tptp_v7_0_0_0Parser.File_nameContext):
        pass

    # Exit a parse tree produced by tptp_v7_0_0_0Parser#file_name.
    def exitFile_name(self, ctx: tptp_v7_0_0_0Parser.File_nameContext):
        pass



import sqlalchemy as sqla
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relation
from sqlalchemy.orm import relationship
from gavel.dialects.db.connection import with_session, get_or_create, get_or_None
from gavel.logic.problem import AnnotatedFormula
from gavel.dialects.db.connection import get_engine

Base = declarative_base()


class Source(Base):
    __tablename__ = "source"
    id = sqla.Column(sqla.Integer, primary_key=True)
    path = sqla.Column(sqla.String, unique=True)


class Formula(Base):
    __tablename__ = "formula"
    id = sqla.Column(sqla.Integer, primary_key=True)
    name = sqla.Column(sqla.Text)
    source_id = sqla.Column(sqla.Integer, sqla.ForeignKey(Source.id), nullable=False)
    source = relationship(Source)
    logic = sqla.VARCHAR(4)
    json = sqla.Column(sqla.JSON)



association_premises = sqla.Table(
    "association",
    Base.metadata,
    sqla.Column("left_id", sqla.Integer, sqla.ForeignKey("problem.id"), nullable=False),
    sqla.Column(
        "right_id", sqla.Integer, sqla.ForeignKey("formula.id"), nullable=False
    ),
)


class SolutionItem(Base):
    id = sqla.Column(sqla.Integer, primary_key=True)
    __tablename__ = "solution_item"
    solution_id = sqla.Column(
        sqla.Integer, sqla.ForeignKey("solution.id"), nullable=False
    )
    solution = relationship("Solution")
    premise_id = sqla.Column(sqla.Integer, sqla.ForeignKey(Formula.id), nullable=False)
    premise = relationship(Formula)
    used = sqla.Column(sqla.Boolean)


class Problem(Base):
    __tablename__ = "problem"
    id = sqla.Column(sqla.Integer, primary_key=True)
    source_id = sqla.Column(sqla.Integer, sqla.ForeignKey(Source.id), nullable=False)
    source = relationship(Source)
    conjecture_id = sqla.Column(
        sqla.Integer, sqla.ForeignKey(Formula.id), nullable=False
    )
    conjecture = relationship(Formula)
    premises = relation(Formula, secondary=association_premises)
    solutions = relation("Solution")

    def create_problem_file(self, file):
        for premise in self.premises:
            file.write(premise.original)


class Solution(Base):
    __tablename__ = "solution"
    id = sqla.Column(sqla.Integer, primary_key=True)
    problem_id = sqla.Column(sqla.Integer, sqla.ForeignKey("problem.id"))
    problem = relationship(Problem)
    premises = relation(SolutionItem)


def create_tables():
    print("Build datastructures")
    metadata = Base.metadata
    metadata.bind = get_engine()
    metadata.create_all()


def drop_tables(tables=None):
    print("Destroy datastructures")
    metadata = Base.metadata
    metadata.bind = get_engine()
    metadata.drop_all(tables=tables)


@with_session
def store_formula(source, struc: AnnotatedFormula, session=None):
    source, created = get_or_create(session, Source, path=source)
    structure = None
    if not created:
        structure = get_or_None(session, Formula, name=struc.name, source=source)
    if structure is None:
        struc.source = source
        session.add(struc)
        session.commit()
        return True
    else:
        return False
